summaryrefslogtreecommitdiffstats
path: root/kalzium/src/timewidget_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalzium/src/timewidget_impl.h')
-rw-r--r--kalzium/src/timewidget_impl.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kalzium/src/timewidget_impl.h b/kalzium/src/timewidget_impl.h
index b728b435..8a3bf770 100644
--- a/kalzium/src/timewidget_impl.h
+++ b/kalzium/src/timewidget_impl.h
@@ -26,10 +26,10 @@ class TimeWidgetIMPL : public TimeWidget
public:
/**
* @param tqparent The tqparent of this widget
* @param name The name of this widget
*/
- TimeWidgetIMPL( TQWidget *tqparent = 0, const char* name = 0 );
+ TimeWidgetIMPL( TQWidget *parent = 0, const char* name = 0 );
public slots:
/**
@@ -26,10 +26,10 @@ class TimeWidgetIMPL : public TimeWidget
public:
/**
- * @param tqparent The tqparent of this widget
+ * @param parent The parent of this widget
* @param name The name of this widget
*/